@@ -87,12 +87,7 @@ public:
     DUrl &operator=(const DUrl &other);
     DUrl &operator=(DUrl &&other);
 
-
-#ifdef QT_NO_URL_CAST_FROM_STRING
     explicit DUrl(const QString &url, ParsingMode mode = TolerantMode);
-#else
-    explicit DUrl(const QString &url, ParsingMode mode = TolerantMode);
-#endif
 
     void setPath(const QString &path, ParsingMode mode = DecodedMode, bool makeAbsolutePath = true);
     void setScheme(const QString &scheme, bool makeAbsolutePath = true);
